@@ -24,7 +24,7 @@
  * @author     Yomei Komiya
  * @copyright  2008 the original author or authors.
  * @license    http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
- * @version    SVN: $Id: TestCase.php 272 2008-03-29 13:04:42Z whitestar $
+ * @version    SVN: $Id: TestCase.php 323 2008-08-02 09:16:48Z whitestar $
  * @link       http://phpcommons.sourceforge.jp/
  * @see        
  * @since      File available since Release 0.9.0
@@ -48,12 +48,43 @@ use Commons::Test::TestUtils;
  * @author     Yomei Komiya
  * @copyright  2008 the original author or authors.
  * @license    http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
- * @version    Release: 1.0.1.1
+ * @version    Release: 1.0.2
  * @link       http://phpcommons.sourceforge.jp/
  * @see        
  * @since      Class available since Release 0.9.0
  */
 abstract class Commons_Test_TestCase extends PHPUnit_Framework_TestCase {
+	
+	/**
+	 * Returns a mock object for the specified class.
+     *
+     * @param  string  $className
+     * @param  array   $arguments
+     * @param  string  $mockClassName
+     * @param  boolean $callOriginalConstructor
+     * @param  boolean $callOriginalClone
+     * @param  boolean $callAutoload
+     * @return object
+     * @since  Method available since Release 1.0.2
+	 */
+	protected function createMock(
+		$className,
+		$arguments = array(),
+		$mockClassName = '',
+		$callOriginalConstructor = true,
+		$callOriginalClone = true,
+		$callAutoload = true) {
+		
+		return $this->getMock(
+			$className,
+			get_class_methods($className),
+			$arguments,
+			$mockClassName,
+			$callOriginalConstructor,
+			$callOriginalClone,
+			$callAutoload);
+	}
+	
 
 	/**
 	 * Tests whether runkit is available or not.
